function [theta]=parameter_ENV(SST, TEMP, AILE, FOR,ny)

%INPUTS see parameters_Lifecycle.xls for details on matrix and anme/
%contrainst on parameters

% SST matrix (ny*3) with ny= number of years 
% columns are the SST per sector: 1. Juv; 2. winter 2; 3. repro

% TEMP vector ny*1: vector of temperature recorded by GLS

% AILE vector ny*1:: vector of wing measurements

% FOR matrix (ny*3) 
% column are: 1. FOR, 2. ACT, 3. RET {note that RET is predicted by TEMP}

% OUTPUT vector of parameters

%%
theta=zeros(68, ny);

%% Juveniles

% first year survival
theta(1,:)=invlogit((-0.23-0.24.*SST(:,1)-0.32.*SST(:,1).^2)+0.368056458*AILE(:,1)); % relationship without outlier;

% survival other stages (see numbering on the life cycle)
theta(2,:)=ones(1,ny).*0.93;
theta(3,:)= theta(2,:);
theta(4,:)= theta(2,:);
theta(5,:)= theta(2,:);
theta(6,:)= theta(2,:);
theta(7,:)= theta(2,:);
theta(8,:)= theta(2,:);
theta(9,:)= theta(2,:);
theta(10,:)= theta(2,:);
theta(11,:)= ones(1,ny).*0.94;
theta(12,:)= theta(11,:);
theta(13,:)= theta(11,:);
theta(14,:)= theta(11,:);
theta(15,:)= theta(11,:);
theta(16,:)= theta(11,:);
theta(17,:)= ones(1,ny).*0.92;
theta(18,:)= theta(17,:);
theta(19,:)= theta(17,:);
theta(20,:)= theta(17,:);
theta(21,:)= theta(17,:);
theta(22,:)= theta(17,:);
theta(23,:)= theta(11,:);
theta(24,:)= theta(17,:);
theta(25,:)= theta(17,:);

% recruitment proba function of wing length
theta(26,:)=invlogit(-4.891594061+0.385926122.*AILE(:,1));
theta(27,:)=invlogit(-3.556583792+0.385926122.*AILE(:,1));
theta(28,:)=invlogit(-2.247152916+0.385926122.*AILE(:,1));
theta(29,:)=invlogit(-1.511223273+0.385926122.*AILE(:,1));
theta(30,:)=invlogit(-1.108869401+0.385926122.*AILE(:,1));
theta(31,:)=invlogit(-0.772677029++0.385926122.*AILE(:,1));

% Breed successfully for the first time, function of SST: 
%   theta 32: given ind recruits at age 5, probability it breeds successfully;
theta(32,:)=invlogit(-0.300619322-0.154409282.*SST(:,2)-0.049391794.*SST(:,2).^2+0.135000818.*SST(:,3)+0.135000818.*SST(:,3).^2);

%   theta 34: given ind recruits at age 7, probability it breeds successfully;
%   theta 35: given ind recruits at age 8, probability it breeds successfully;
%   theta 36: given ind recruits at age 9, probability it breeds successfully;
%   theta 37: given ind recruits from age 10 onwards, probability it breeds successfully;

theta(33,:)= theta(32,:);
theta(34,:)= theta(32,:);
theta(35,:)= theta(32,:);
theta(36,:)= theta(32,:);
theta(37,:)= theta(32,:);

%% Experienced breeders
% breeders that have previoulsy breed once: 
% success function of foraging behaviors
% breeding function of SST

%   theta 38: Probability a 5 year-old successful first-time breeder at t breeds at t+1;
bs=1.284297702-0.154409282.*SST(:,2)-0.049391794.*SST(:,2).^2+0.135000818.*SST(:,3)+0.124121331.*SST(:,3).^2;
cs=0.65367776+0.030113582.*SST(:,2)-0.057345669.*SST(:,2).^2+0.2029.*SST(:,3)+0.0783.*SST(:,3).^2;
theta(38,:)=invlogitG(bs,cs)+invlogitG(cs,bs);

%   theta 39: Probability a 6 year-old successful first-time breeder at t breeds  at t+1;
%   theta 40: Probability a 7 year-old successful first-time breeder at t breeds  at t+1;
%   theta 41: Probability a 8 year-old successful first-time breeder at t breeds  at t+1;
%   theta 42: Probability a 9 year-old successful first-time breeder at t breeds  at t+1;
%   theta 43: Probability a 10 year-old or older successful first-time breeder at t breeds at t+1;
theta(39,:)= theta(38,:);
theta(40,:)= theta(38,:);
theta(41,:)= theta(38,:);
theta(42,:)= theta(38,:);
theta(43,:)= theta(38,:);
%   theta 50: probability that a successful experienced breeder at t breeds at t+1; 
theta(50,:)= theta(38,:);


% theta 53: probability that a 5 year old successful breeder at t raises successfully a chick at t+1; 
RETs=exp(5.494+0.05-0.015.*TEMP);
RETs=(RETs-248.8625954)./10.59881224;
gammas=invlogit(0.9785+0.4366.*RETs+1.3643.*FOR(:,1)-0.4593.*FOR(:,2));

theta(53,:)=gammas;
%   theta 54: probability that a 6 year old successful breeder at t raises successfully a chick at t+1; 
%   theta 55: probability that a 7 year old successful breeder at t raises successfully a chick at t+1;
%   theta 56: probability that a 8 year old successful breeder at t raises successfully a chick at t+1; 
%   theta 57: probability that a 9 year old successful breeder at t raises successfully a chick at t+1; 
%   theta 58: probability that a 10 year old or older successful breeder at t raises successfully a chick at t+1; 

theta(54,:)= theta(53,:);
theta(55,:)= theta(53,:);
theta(56,:)= theta(53,:);
theta(57,:)= theta(53,:);
theta(58,:)= theta(53,:);

%   theta 65: probability that a successful experienced breeder at t raises successfully a chick at t+1; 
theta(65,:)= theta(53,:);


%   theta 44: Probability a 5 year-old failed first-time breeder at t breeds at t+1;
bf=0.81440189-0.154409282.*SST(:,2)-0.049391794.*SST(:,2).^2+0.135000818.*SST(:,3)+0.124121331.*SST(:,3).^2;
cf=0.390548647+0.030113582.*SST(:,2)-0.057345669.*SST(:,2).^2+0.2029.*SST(:,3)+0.0783.*SST(:,3).^2;

theta(44,:)=invlogitG(bf,cf)+invlogitG(cf,bf);

%   theta 45: Probability a 6 year-old failed first-time breeder at t breeds  at t+1;
%   theta 46: Probability a 7 year-old failed first-time breeder at t breeds  at t+1;
%   theta 47: Probability a 8 year-old failed first-time breeder at t breeds  at t+1;
%   theta 48: Probability a 9 year-old failed first-time breeder at t breeds  at t+1;
%   theta 49: Probability a 10 year-old or older failed first-time breeder at t breeds  at t+1;

theta(45,:)= theta(44,:);
theta(46,:)= theta(44,:);
theta(47,:)= theta(44,:);
theta(48,:)= theta(44,:);
theta(49,:)= theta(44,:);

%   theta 51: probability that a failed experienced breeder at t breeds  at t+1; 
theta(51,:)= theta(44,:);

%   theta 59: probability that a 5 year old failed breeder at t raises successfully a chick at t+1; 
RETf=exp(5.494-0.015.*TEMP);
RETf=(RETf-248.8625954)./10.59881224;
gammaf=invlogit(0.9785+0.4366.*RETf+1.3643.*FOR(:,1)-0.4593.*FOR(:,2));

theta(59,:)= gammaf;

%   theta 60: probability that a 6 year old failed breeder at t raises successfully a chick at t+1; 
%   theta 61: probability that a 7 year old failed breeder at t raises successfully a chick at t+1; 
%   theta 62: probability that a 8 year old failed breeder at t raises successfully a chick at t+1; 
%   theta 63: probability that a 9 year old failed breeder at t raises successfully a chick at t+1; 
%   theta 64: probability that a 10 year old or older failed breeder at t raises successfully a chick at t+1; 

theta(60,:)= theta(59,:);
theta(61,:)= theta(59,:);
theta(62,:)= theta(59,:);
theta(63,:)= theta(59,:);
theta(64,:)= theta(59,:);

%   theta 66: probability that a failed experienced breeder at t raises successfully a chick at t+1; 
theta(66,:)= theta(59,:);
%   theta 67: probability that a skipper at t raises successfully a chick at t+1; 
theta(67,:)=theta(59,:);


% SKIPPERS
bnb=0.013026711-0.154409282.*SST(:,2)-0.049391794.*SST(:,2).^2+0.135000818.*SST(:,3)+0.124121331.*SST(:,3).^2;
cnb=-0.2112+0.030113582.*SST(:,2)-0.057345669.*SST(:,2).^2+0.2029.*SST(:,3)+0.0783.*SST(:,3).^2;

%theta 52: probability that a skipper at t breeds successfully at t+1;
theta(52,:)=invlogitG(bnb,cnb)+invlogitG(cnb,bnb);


theta(68,:)=ones(1,ny).*0.50;



%return